
# Slot: has biological sequence


The state of the sequence w.r.t a reference sequence

URI: [biolink:sequence_variant_has_biological_sequence](https://w3id.org/biolink/vocab/sequence_variant_has_biological_sequence)


## Domain and Range

[SequenceVariant](SequenceVariant.md) &#8594;  <sub>0..1</sub> [BiologicalSequence](types/BiologicalSequence.md)

## Parents

 *  is_a: [has biological sequence](has_biological_sequence.md)

## Children


## Used by

 * [SequenceVariant](SequenceVariant.md)
 * [Snv](Snv.md)
